@@ -65,8 +65,7 @@ which needs to be better organized via functions */
 #define SUMMARY_FOLLOWUP_FLAGS	" mapi:int:0x1090" /* PidTagFlagStatus */ \
 				" mapi:time:0x1091" /* PidTagFlagCompleteTime */ \
 				" mapi:dist:string:Common:0x8530" /* PidLidFlagRequest */ \
-				" mapi:dist:time:Task:0x8105" /* PidLidTaskDueDate */ \
-				" mapi:string:0x007D" /* PidTagTransportMessageHeaders */
+				" mapi:dist:time:Task:0x8105" /* PidLidTaskDueDate */
 
 #define SUMMARY_ITEM_FLAGS "item:ResponseObjects item:Sensitivity item:Importance item:Categories" SUMMARY_FOLLOWUP_FLAGS
 #define ITEM_PROPS "item:Subject item:DateTimeReceived item:DateTimeSent item:DateTimeCreated item:Size " \
@@ -606,7 +605,7 @@ ews_folder_maybe_update_mlist (CamelFolder *folder,
 		}
 	}
 
-	camel_message_info_free ((CamelMessageInfo *) mi);
+	camel_message_info_unref (mi);
 }
 
 /* Get the message from cache if available otherwise get it from server */
@@ -825,7 +824,7 @@ msg_update_flags (ESoapMessage *msg,
 
 		camel_folder_summary_touch (mi->info.summary);
 
-		camel_message_info_free (mi);
+		camel_message_info_unref (mi);
 	}
 	/* Don't think we need to free the list; we already freed every element */
 }
@@ -866,34 +865,6 @@ ews_sync_mi_flags (CamelFolder *folder,
 	return res;
 }
 
-static gboolean
-ews_save_flags (CamelFolder *folder,
-		GSList *mi_list,
-		GCancellable *cancellable,
-		GError **error)
-{
-	gboolean ret;
-	GError *local_error = NULL;
-
-	ret = ews_sync_mi_flags (folder, mi_list, cancellable, &local_error);
-
-	if (local_error != NULL) {
-		if (g_error_matches (local_error, EWS_CONNECTION_ERROR, EWS_CONNECTION_ERROR_ACCESSDENIED)) {
-			/*
-			 * If cannot save flags, then it can be a public
-			 * or a foreign folder with no write access;
-			 * the flags will be saved locally, at least
-			 */
-			g_clear_error (&local_error);
-			ret = TRUE;
-		} else {
-			g_propagate_error (error, local_error);
-		}
-	}
-
-	return ret;
-}
-
 static gboolean
 ews_folder_is_of_type (CamelFolder *folder,
                        guint32 folder_type)
@@ -978,13 +949,13 @@ ews_move_to_junk_folder (CamelFolder *folder,
 			for (iter = junk_uids; iter; iter = g_slist_next (iter)) {
 				const gchar *uid = iter->data;
 
-				camel_folder_summary_lock (folder->summary, CAMEL_FOLDER_SUMMARY_SUMMARY_LOCK);
+				camel_folder_summary_lock (folder->summary);
 
 				camel_folder_change_info_remove_uid (changes, uid);
 				camel_folder_summary_remove_uid (folder->summary, uid);
 				ews_data_cache_remove (ews_folder->cache, "cur", uid, NULL);
 
-				camel_folder_summary_unlock (folder->summary, CAMEL_FOLDER_SUMMARY_SUMMARY_LOCK);
+				camel_folder_summary_unlock (folder->summary);
 			}
 
 			if (camel_folder_change_info_changed (changes)) {
@@ -1051,7 +1022,7 @@ ews_synchronize_sync (CamelFolder *folder,
 		 * for most flags — not even replied/forwarded. */
 		if ((flags_set & CAMEL_MESSAGE_FOLDER_FLAGGED) != 0 &&
 		    (flags_changed & (CAMEL_MESSAGE_SEEN | CAMEL_MESSAGE_ANSWERED | CAMEL_MESSAGE_FORWARDED | CAMEL_MESSAGE_FLAGGED)) != 0) {
-			mi_list = g_slist_prepend (mi_list, mi);
+			mi_list = g_slist_append (mi_list, mi);
 			mi_list_len++;
 
 			if (flags_set & CAMEL_MESSAGE_DELETED)
@@ -1060,27 +1031,35 @@ ews_synchronize_sync (CamelFolder *folder,
 				junk_uids = g_slist_prepend (junk_uids, (gpointer) camel_pstring_strdup (uids->pdata[i]));
 		} else if (flags_set & CAMEL_MESSAGE_DELETED) {
 			deleted_uids = g_slist_prepend (deleted_uids, (gpointer) camel_pstring_strdup (uids->pdata[i]));
-			camel_message_info_free (mi);
+			camel_message_info_unref (mi);
 		} else if (flags_set & CAMEL_MESSAGE_JUNK) {
 			junk_uids = g_slist_prepend (junk_uids, (gpointer) camel_pstring_strdup (uids->pdata[i]));
-			camel_message_info_free (mi);
+			camel_message_info_unref (mi);
 		} else if ((flags_set & CAMEL_MESSAGE_FOLDER_FLAGGED) != 0) {
 			/* OK, the change must have been the labels */
-			mi_list = g_slist_prepend (mi_list, mi);
+			mi_list = g_slist_append (mi_list, mi);
 			mi_list_len++;
 		} else {
-			camel_message_info_free (mi);
+			camel_message_info_unref (mi);
 		}
 
 		if (mi_list_len == EWS_MAX_FETCH_COUNT) {
-			success = ews_save_flags (folder, mi_list, cancellable, &local_error);
+			success = ews_sync_mi_flags (folder, mi_list, cancellable, &local_error);
 			mi_list = NULL;
 			mi_list_len = 0;
 		}
 	}
 
-	if (mi_list != NULL && success)
-		success = ews_save_flags (folder, mi_list, cancellable, &local_error);
+	if (mi_list_len && success) {
+		success = ews_sync_mi_flags (folder, mi_list, cancellable, &local_error);
+		if (local_error && g_error_matches (local_error, EWS_CONNECTION_ERROR, EWS_CONNECTION_ERROR_ACCESSDENIED)) {
+			/* if cannot save flags, then it can be a public or
+			   a foreign folder with no write access;
+			   the flags will be saved locally, at least */
+			g_clear_error (&local_error);
+			success = TRUE;
+		}			
+	}
 
 	if (deleted_uids && success)
 		success = ews_delete_messages (folder, deleted_uids, ews_folder_is_of_type (folder, CAMEL_FOLDER_TYPE_TRASH), cancellable, &local_error);
@@ -1264,8 +1243,8 @@ sync_updated_items (CamelEwsFolder *ews_folder,
 		}
 
 		/* Check if the item has really changed */
-		if (!g_strcmp0 (((CamelEwsMessageInfo *) mi)->change_key, id->change_key)) {
-			camel_message_info_free (mi);
+		if (!strcmp (((CamelEwsMessageInfo *) mi)->change_key, id->change_key)) {
+			camel_message_info_unref (mi);
 			g_object_unref (item);
 			continue;
 		}
@@ -1275,7 +1254,7 @@ sync_updated_items (CamelEwsFolder *ews_folder,
 		else
 			msg_ids = g_slist_append (msg_ids, g_strdup (id->id));
 
-		camel_message_info_free (mi);
+		camel_message_info_unref (mi);
 		g_object_unref (item);
 	}
 	g_slist_free (updated_items);
@@ -1444,7 +1423,7 @@ ews_folder_forget_all_mails (CamelEwsFolder *ews_folder)
 
 	changes = camel_folder_change_info_new ();
 
-	camel_folder_summary_lock (folder->summary, CAMEL_FOLDER_SUMMARY_SUMMARY_LOCK);
+	camel_folder_summary_lock (folder->summary);
 	for (ii = 0; ii < known_uids->len; ii++) {
 		const gchar *uid = g_ptr_array_index (known_uids, ii);
 
@@ -1452,7 +1431,7 @@ ews_folder_forget_all_mails (CamelEwsFolder *ews_folder)
 		camel_folder_summary_remove_uid (folder->summary, uid);
 		ews_data_cache_remove (ews_folder->cache, "cur", uid, NULL);
 	}
-	camel_folder_summary_unlock (folder->summary, CAMEL_FOLDER_SUMMARY_SUMMARY_LOCK);
+	camel_folder_summary_unlock (folder->summary);
 
 	if (camel_folder_change_info_changed (changes)) {
 		camel_folder_summary_touch (folder->summary);
@@ -1675,9 +1654,8 @@ ews_transfer_messages_to_sync (CamelFolder *source,
 	const gchar *dst_full_name;
 	gchar *dst_id;
 	GError *local_error = NULL;
-	GSList *ids = NULL, *ret_items = NULL, *mi_list = NULL;
-	gint i = 0, mi_list_len = 0;
-	gboolean success = TRUE;
+	GSList *ids = NULL, *ret_items = NULL;
+	gint i = 0;
 
 	dst_full_name = camel_folder_get_full_name (destination);
 	dst_ews_store = (CamelEwsStore *) camel_folder_get_parent_store (destination);
@@ -1689,38 +1667,11 @@ ews_transfer_messages_to_sync (CamelFolder *source,
 	dst_id = camel_ews_store_summary_get_folder_id_from_name (
 		dst_ews_store->summary, dst_full_name);
 
-	for (i = 0; success && i < uids->len; i++) {
-		guint32 flags_set;
-		CamelEwsMessageInfo *mi;
-
-		ids = g_slist_prepend (ids, (gchar *) uids->pdata[i]);
-
-		mi = (gpointer) camel_folder_summary_get (source->summary, uids->pdata[i]);
-		if (!mi)
-			continue;
-
-		flags_set = camel_message_info_flags (mi);
-
-		/* Exchange doesn't seem to have a sane representation
-		 * for most flags — not even replied/forwarded. */
-		if ((flags_set & CAMEL_MESSAGE_FOLDER_FLAGGED) != 0) {
-			mi_list = g_slist_prepend (mi_list, mi);
-			mi_list_len++;
-		} else {
-			camel_message_info_free (mi);
-		}
-
-		if (mi_list_len == EWS_MAX_FETCH_COUNT) {
-			success = ews_save_flags (source, mi_list, cancellable, &local_error);
-			mi_list = NULL;
-			mi_list_len = 0;
-		}
+	for (i = 0; i < uids->len; i++) {
+		ids = g_slist_append (ids, (gchar *) uids->pdata[i]);
 	}
 
-	if (mi_list != NULL && success)
-		success = ews_save_flags (source, mi_list, cancellable, &local_error);
-
-	if (success && e_ews_connection_move_items_sync (
+	if (e_ews_connection_move_items_sync (
 		cnc, EWS_PRIORITY_MEDIUM,
 		dst_id, !delete_originals,
 		ids, &ret_items,
@@ -1807,11 +1758,11 @@ ews_delete_messages (CamelFolder *folder,
 		if (status) {
 			while (deleted_items) {
 				const gchar *uid = (gchar *) deleted_items->data;
-				camel_folder_summary_lock (folder->summary, CAMEL_FOLDER_SUMMARY_SUMMARY_LOCK);
+				camel_folder_summary_lock (folder->summary);
 				camel_folder_change_info_remove_uid (changes, uid);
 				camel_folder_summary_remove_uid (folder->summary, uid);
 				ews_data_cache_remove (ews_folder->cache, "cur", uid, NULL);
-				camel_folder_summary_unlock (folder->summary, CAMEL_FOLDER_SUMMARY_SUMMARY_LOCK);
+				camel_folder_summary_unlock (folder->summary);
 				deleted_items = g_slist_next (deleted_items);
 			}
 		}
@@ -1872,7 +1823,7 @@ ews_expunge_sync (CamelFolder *folder,
 		if (ews_info && (is_trash || (ews_info->info.flags & CAMEL_MESSAGE_DELETED) != 0))
 			deleted_items = g_slist_prepend (deleted_items, (gpointer) camel_pstring_strdup (uid));
 
-		camel_message_info_free (info);
+		camel_message_info_unref (info);
 	}
 
 	camel_folder_summary_free_array (known_uids);
