@@ -753,7 +753,7 @@ camel_ews_utils_sync_updated_items (CamelEwsFolder *ews_folder,
 				mi->info.flags = mi->info.flags & (~CAMEL_MESSAGE_FOLDER_FLAGGED);
 			}
 
-			camel_message_info_free (mi);
+			camel_message_info_unref (mi);
 			g_object_unref (item);
 			continue;
 		}
@@ -793,8 +793,7 @@ camel_ews_utils_sync_created_items (CamelEwsFolder *ews_folder,
 		const EwsMailbox *from;
 		EEwsItemType item_type;
 		const GSList *to, *cc;
-		const gchar *msg_headers;
-		gboolean has_attachments, found_property;
+		gboolean has_attachments;
 		guint32 server_flags;
 
 		if (!item)
@@ -809,38 +808,13 @@ camel_ews_utils_sync_created_items (CamelEwsFolder *ews_folder,
 		mi = (CamelEwsMessageInfo *)
 			camel_folder_summary_get (folder->summary, id->id);
 		if (mi) {
-			camel_message_info_free (mi);
+			camel_message_info_unref (mi);
 			g_object_unref (item);
 			continue;
 		}
 
-
-		/* PidTagTransportMessageHeaders */
-		found_property = FALSE;
-		msg_headers = e_ews_item_get_extended_property_as_string (item, NULL, 0x007D, &found_property);
-		if (!found_property)
-			msg_headers = NULL;
-
-		if (msg_headers && *msg_headers) {
-			CamelMimePart *part = camel_mime_part_new ();
-			CamelStream *stream;
-			CamelMimeParser *parser;
-
-			stream = camel_stream_mem_new_with_buffer (msg_headers, strlen (msg_headers));
-			parser = camel_mime_parser_new ();
-			camel_mime_parser_init_with_stream (parser, stream, NULL);
-			camel_mime_parser_scan_from (parser, FALSE);
-			g_object_unref (stream);
-
-			if (camel_mime_part_construct_from_parser_sync (part, parser, NULL, NULL))
-				mi = (CamelEwsMessageInfo *) camel_folder_summary_info_new_from_header (folder->summary, part->headers);
-
-			g_object_unref (parser);
-			g_object_unref (part);
-		}
-
-		if (!mi)
-			mi = (CamelEwsMessageInfo *) camel_message_info_new (folder->summary);
+		mi = (CamelEwsMessageInfo *)
+			camel_message_info_new (folder->summary);
 
 		if (mi->info.content == NULL) {
 			mi->info.content =
