@@ -214,6 +214,9 @@ void		e_ews_connection_utils_unref_in_thread
 GType		e_ews_connection_get_type	(void);
 EEwsConnection *e_ews_connection_new		(const gchar *uri,
 						 CamelEwsSettings *settings);
+EEwsConnection *e_ews_connection_new_full	(const gchar *uri,
+						 CamelEwsSettings *settings,
+						 gboolean allow_connection_reuse);
 const gchar *	e_ews_connection_get_uri	(EEwsConnection *cnc);
 const gchar *	e_ews_connection_get_password	(EEwsConnection *cnc);
 gchar *		e_ews_connection_dup_password	(EEwsConnection *cnc);
@@ -333,6 +336,12 @@ gboolean	e_ews_connection_find_folder_items_sync
 EEwsServerVersion
 		e_ews_connection_get_server_version
 						(EEwsConnection *cnc);
+void		e_ews_connection_set_server_version
+						(EEwsConnection *cnc,
+						 EEwsServerVersion version);
+void		e_ews_connection_set_server_version_from_string
+						(EEwsConnection *cnc,
+						 const gchar *version);
 gboolean	e_ews_connection_satisfies_server_version
 						(EEwsConnection *cnc,
 						 EEwsServerVersion versio);
@@ -601,6 +610,29 @@ gboolean	e_ews_connection_delete_folder_sync
 						 GCancellable *cancellable,
 						 GError **error);
 
+void		e_ews_connection_empty_folder	(EEwsConnection *cnc,
+						 gint pri,
+						 const gchar *folder_id,
+						 gboolean is_distinguished_id,
+						 const gchar *delete_type,
+						 gboolean delete_subfolders,
+						 GCancellable *cancellable,
+						 GAsyncReadyCallback callback,
+						 gpointer user_data);
+gboolean	e_ews_connection_empty_folder_finish
+						(EEwsConnection *cnc,
+						 GAsyncResult *result,
+						 GError **error);
+gboolean	e_ews_connection_empty_folder_sync
+						(EEwsConnection *cnc,
+						 gint pri,
+						 const gchar *folder_id,
+						 gboolean is_distinguished_id,
+						 const gchar *delete_type,
+						 gboolean delete_subfolders,
+						 GCancellable *cancellable,
+						 GError **error);
+
 void		e_ews_connection_update_folder	(EEwsConnection *cnc,
 						 gint pri,
 						 EEwsRequestCreationCallback create_cb,
@@ -1022,6 +1054,23 @@ gboolean	e_ews_connection_find_folder_sync
 						 GSList **folders,
 						 GCancellable *cancellable,
 						 GError **error);
+void		e_ews_connection_query_auth_methods
+						(EEwsConnection *cnc,
+						 gint pri,
+						 GCancellable *cancellable,
+						 GAsyncReadyCallback callback,
+						 gpointer user_data);
+gboolean	e_ews_connection_query_auth_methods_finish
+						(EEwsConnection *cnc,
+						 GAsyncResult *result,
+						 GSList **auth_methods,
+						 GError **error);
+gboolean	e_ews_connection_query_auth_methods_sync
+						(EEwsConnection *cnc,
+						 gint pri,
+						 GSList **auth_methods,
+						 GCancellable *cancellable,
+						 GError **error);
 
 G_END_DECLS
 
